Documentation
¶
Index ¶
- Constants
- Variables
- func And(predicates ...predicate.Organization) predicate.Organization
- func HasUsers() predicate.Organization
- func HasUsersWith(preds ...predicate.User) predicate.Organization
- func ID(id int) predicate.Organization
- func IDEQ(id int) predicate.Organization
- func IDGT(id int) predicate.Organization
- func IDGTE(id int) predicate.Organization
- func IDIn(ids ...int) predicate.Organization
- func IDLT(id int) predicate.Organization
- func IDLTE(id int) predicate.Organization
- func IDNEQ(id int) predicate.Organization
- func IDNotIn(ids ...int) predicate.Organization
- func Name(v string) predicate.Organization
- func NameContains(v string) predicate.Organization
- func NameContainsFold(v string) predicate.Organization
- func NameEQ(v string) predicate.Organization
- func NameEqualFold(v string) predicate.Organization
- func NameGT(v string) predicate.Organization
- func NameGTE(v string) predicate.Organization
- func NameHasPrefix(v string) predicate.Organization
- func NameHasSuffix(v string) predicate.Organization
- func NameIn(vs ...string) predicate.Organization
- func NameLT(v string) predicate.Organization
- func NameLTE(v string) predicate.Organization
- func NameNEQ(v string) predicate.Organization
- func NameNotIn(vs ...string) predicate.Organization
- func Not(p predicate.Organization) predicate.Organization
- func Or(predicates ...predicate.Organization) predicate.Organization
- func ValidColumn(column string) bool
- type OrderOption
Constants ¶
const ( // Label holds the string label denoting the organization type in the database. Label = "organization" // FieldID holds the string denoting the id field in the database. FieldID = "id" // FieldName holds the string denoting the name field in the database. FieldName = "name" // EdgeUsers holds the string denoting the users edge name in mutations. EdgeUsers = "users" // Table holds the table name of the organization in the database. Table = "organizations" // UsersTable is the table that holds the users relation/edge. The primary key declared below. UsersTable = "organization_users" // UsersInverseTable is the table name for the User entity. // It exists in this package in order to avoid circular dependency with the "user" package. UsersInverseTable = "users" )
Variables ¶
var Columns = []string{ FieldID, FieldName, }
Columns holds all SQL columns for organization fields.
var ForeignKeys = []string{
"user_tenant",
}
ForeignKeys holds the SQL foreign-keys that are owned by the "organizations" table and are not defined as standalone fields in the schema.
var ( // UsersPrimaryKey and UsersColumn2 are the table columns denoting the // primary key for the users relation (M2M). UsersPrimaryKey = []string{"organization_id", "user_id"} )
Functions ¶
func And ¶
func And(predicates ...predicate.Organization) predicate.Organization
And groups predicates with the AND operator between them.
func HasUsers ¶
func HasUsers() predicate.Organization
HasUsers applies the HasEdge predicate on the "users" edge.
func HasUsersWith ¶
func HasUsersWith(preds ...predicate.User) predicate.Organization
HasUsersWith applies the HasEdge predicate on the "users" edge with a given conditions (other predicates).
func IDGTE ¶
func IDGTE(id int) predicate.Organization
IDGTE applies the GTE predicate on the ID field.
func IDIn ¶
func IDIn(ids ...int) predicate.Organization
IDIn applies the In predicate on the ID field.
func IDLTE ¶
func IDLTE(id int) predicate.Organization
IDLTE applies the LTE predicate on the ID field.
func IDNEQ ¶
func IDNEQ(id int) predicate.Organization
IDNEQ applies the NEQ predicate on the ID field.
func IDNotIn ¶
func IDNotIn(ids ...int) predicate.Organization
IDNotIn applies the NotIn predicate on the ID field.
func Name ¶
func Name(v string) predicate.Organization
Name applies equality check predicate on the "name" field. It's identical to NameEQ.
func NameContains ¶
func NameContains(v string) predicate.Organization
NameContains applies the Contains predicate on the "name" field.
func NameContainsFold ¶
func NameContainsFold(v string) predicate.Organization
NameContainsFold applies the ContainsFold predicate on the "name" field.
func NameEQ ¶
func NameEQ(v string) predicate.Organization
NameEQ applies the EQ predicate on the "name" field.
func NameEqualFold ¶
func NameEqualFold(v string) predicate.Organization
NameEqualFold applies the EqualFold predicate on the "name" field.
func NameGT ¶
func NameGT(v string) predicate.Organization
NameGT applies the GT predicate on the "name" field.
func NameGTE ¶
func NameGTE(v string) predicate.Organization
NameGTE applies the GTE predicate on the "name" field.
func NameHasPrefix ¶
func NameHasPrefix(v string) predicate.Organization
NameHasPrefix applies the HasPrefix predicate on the "name" field.
func NameHasSuffix ¶
func NameHasSuffix(v string) predicate.Organization
NameHasSuffix applies the HasSuffix predicate on the "name" field.
func NameIn ¶
func NameIn(vs ...string) predicate.Organization
NameIn applies the In predicate on the "name" field.
func NameLT ¶
func NameLT(v string) predicate.Organization
NameLT applies the LT predicate on the "name" field.
func NameLTE ¶
func NameLTE(v string) predicate.Organization
NameLTE applies the LTE predicate on the "name" field.
func NameNEQ ¶
func NameNEQ(v string) predicate.Organization
NameNEQ applies the NEQ predicate on the "name" field.
func NameNotIn ¶
func NameNotIn(vs ...string) predicate.Organization
NameNotIn applies the NotIn predicate on the "name" field.
func Not ¶
func Not(p predicate.Organization) predicate.Organization
Not applies the not operator on the given predicate.
func Or ¶
func Or(predicates ...predicate.Organization) predicate.Organization
Or groups predicates with the OR operator between them.
func ValidColumn ¶
ValidColumn reports if the column name is valid (part of the table columns).
Types ¶
type OrderOption ¶
OrderOption defines the ordering options for the Organization queries.
func ByID ¶
func ByID(opts ...sql.OrderTermOption) OrderOption
ByID orders the results by the id field.
func ByName ¶
func ByName(opts ...sql.OrderTermOption) OrderOption
ByName orders the results by the name field.
func ByUsers ¶
func ByUsers(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
ByUsers orders the results by users terms.
func ByUsersCount ¶
func ByUsersCount(opts ...sql.OrderTermOption) OrderOption
ByUsersCount orders the results by users count.