Documentation
¶
Index ¶
- Constants
- Variables
- func And(predicates ...predicate.User) predicate.User
- func Email(v string) predicate.User
- func EmailContains(v string) predicate.User
- func EmailContainsFold(v string) predicate.User
- func EmailEQ(v string) predicate.User
- func EmailEqualFold(v string) predicate.User
- func EmailGT(v string) predicate.User
- func EmailGTE(v string) predicate.User
- func EmailHasPrefix(v string) predicate.User
- func EmailHasSuffix(v string) predicate.User
- func EmailIn(vs ...string) predicate.User
- func EmailLT(v string) predicate.User
- func EmailLTE(v string) predicate.User
- func EmailNEQ(v string) predicate.User
- func EmailNotIn(vs ...string) predicate.User
- func HasOrganizations() predicate.User
- func HasOrganizationsWith(preds ...predicate.Organization) predicate.User
- func HasTenant() predicate.User
- func HasTenantWith(preds ...predicate.Organization) predicate.User
- func ID(id int) predicate.User
- func IDEQ(id int) predicate.User
- func IDGT(id int) predicate.User
- func IDGTE(id int) predicate.User
- func IDIn(ids ...int) predicate.User
- func IDLT(id int) predicate.User
- func IDLTE(id int) predicate.User
- func IDNEQ(id int) predicate.User
- func IDNotIn(ids ...int) predicate.User
- func Not(p predicate.User) predicate.User
- func Or(predicates ...predicate.User) predicate.User
- func Password(v string) predicate.User
- func PasswordContains(v string) predicate.User
- func PasswordContainsFold(v string) predicate.User
- func PasswordEQ(v string) predicate.User
- func PasswordEqualFold(v string) predicate.User
- func PasswordGT(v string) predicate.User
- func PasswordGTE(v string) predicate.User
- func PasswordHasPrefix(v string) predicate.User
- func PasswordHasSuffix(v string) predicate.User
- func PasswordIn(vs ...string) predicate.User
- func PasswordLT(v string) predicate.User
- func PasswordLTE(v string) predicate.User
- func PasswordNEQ(v string) predicate.User
- func PasswordNotIn(vs ...string) predicate.User
- func ValidColumn(column string) bool
- type OrderOption
- func ByEmail(opts ...sql.OrderTermOption) OrderOption
- func ByID(opts ...sql.OrderTermOption) OrderOption
- func ByOrganizations(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
- func ByOrganizationsCount(opts ...sql.OrderTermOption) OrderOption
- func ByPassword(opts ...sql.OrderTermOption) OrderOption
- func ByTenant(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
- func ByTenantCount(opts ...sql.OrderTermOption) OrderOption
Constants ¶
const ( // Label holds the string label denoting the user type in the database. Label = "user" // FieldID holds the string denoting the id field in the database. FieldID = "id" // FieldEmail holds the string denoting the email field in the database. FieldEmail = "email" // FieldPassword holds the string denoting the password field in the database. FieldPassword = "password" // EdgeTenant holds the string denoting the tenant edge name in mutations. EdgeTenant = "tenant" // EdgeOrganizations holds the string denoting the organizations edge name in mutations. EdgeOrganizations = "organizations" // Table holds the table name of the user in the database. Table = "users" // TenantTable is the table that holds the tenant relation/edge. TenantTable = "organizations" // TenantInverseTable is the table name for the Organization entity. // It exists in this package in order to avoid circular dependency with the "organization" package. TenantInverseTable = "organizations" // TenantColumn is the table column denoting the tenant relation/edge. TenantColumn = "user_tenant" // OrganizationsTable is the table that holds the organizations relation/edge. The primary key declared below. OrganizationsTable = "organization_users" // OrganizationsInverseTable is the table name for the Organization entity. // It exists in this package in order to avoid circular dependency with the "organization" package. OrganizationsInverseTable = "organizations" )
Variables ¶
var Columns = []string{ FieldID, FieldEmail, FieldPassword, }
Columns holds all SQL columns for user fields.
var ( // EmailValidator is a validator for the "email" field. It is called by the builders before save. EmailValidator func(string) error )
var ( // OrganizationsPrimaryKey and OrganizationsColumn2 are the table columns denoting the // primary key for the organizations relation (M2M). OrganizationsPrimaryKey = []string{"organization_id", "user_id"} )
Functions ¶
func Email ¶
Email applies equality check predicate on the "email" field. It's identical to EmailEQ.
func EmailContains ¶
EmailContains applies the Contains predicate on the "email" field.
func EmailContainsFold ¶
EmailContainsFold applies the ContainsFold predicate on the "email" field.
func EmailEqualFold ¶
EmailEqualFold applies the EqualFold predicate on the "email" field.
func EmailHasPrefix ¶
EmailHasPrefix applies the HasPrefix predicate on the "email" field.
func EmailHasSuffix ¶
EmailHasSuffix applies the HasSuffix predicate on the "email" field.
func EmailNotIn ¶
EmailNotIn applies the NotIn predicate on the "email" field.
func HasOrganizations ¶
HasOrganizations applies the HasEdge predicate on the "organizations" edge.
func HasOrganizationsWith ¶
func HasOrganizationsWith(preds ...predicate.Organization) predicate.User
HasOrganizationsWith applies the HasEdge predicate on the "organizations" edge with a given conditions (other predicates).
func HasTenantWith ¶
func HasTenantWith(preds ...predicate.Organization) predicate.User
HasTenantWith applies the HasEdge predicate on the "tenant" edge with a given conditions (other predicates).
func Password ¶
Password applies equality check predicate on the "password" field. It's identical to PasswordEQ.
func PasswordContains ¶
PasswordContains applies the Contains predicate on the "password" field.
func PasswordContainsFold ¶
PasswordContainsFold applies the ContainsFold predicate on the "password" field.
func PasswordEQ ¶
PasswordEQ applies the EQ predicate on the "password" field.
func PasswordEqualFold ¶
PasswordEqualFold applies the EqualFold predicate on the "password" field.
func PasswordGT ¶
PasswordGT applies the GT predicate on the "password" field.
func PasswordGTE ¶
PasswordGTE applies the GTE predicate on the "password" field.
func PasswordHasPrefix ¶
PasswordHasPrefix applies the HasPrefix predicate on the "password" field.
func PasswordHasSuffix ¶
PasswordHasSuffix applies the HasSuffix predicate on the "password" field.
func PasswordIn ¶
PasswordIn applies the In predicate on the "password" field.
func PasswordLT ¶
PasswordLT applies the LT predicate on the "password" field.
func PasswordLTE ¶
PasswordLTE applies the LTE predicate on the "password" field.
func PasswordNEQ ¶
PasswordNEQ applies the NEQ predicate on the "password" field.
func PasswordNotIn ¶
PasswordNotIn applies the NotIn predicate on the "password" field.
func ValidColumn ¶
ValidColumn reports if the column name is valid (part of the table columns).
Types ¶
type OrderOption ¶
OrderOption defines the ordering options for the User queries.
func ByEmail ¶
func ByEmail(opts ...sql.OrderTermOption) OrderOption
ByEmail orders the results by the email field.
func ByID ¶
func ByID(opts ...sql.OrderTermOption) OrderOption
ByID orders the results by the id field.
func ByOrganizations ¶
func ByOrganizations(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
ByOrganizations orders the results by organizations terms.
func ByOrganizationsCount ¶
func ByOrganizationsCount(opts ...sql.OrderTermOption) OrderOption
ByOrganizationsCount orders the results by organizations count.
func ByPassword ¶
func ByPassword(opts ...sql.OrderTermOption) OrderOption
ByPassword orders the results by the password field.
func ByTenant ¶
func ByTenant(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
ByTenant orders the results by tenant terms.
func ByTenantCount ¶
func ByTenantCount(opts ...sql.OrderTermOption) OrderOption
ByTenantCount orders the results by tenant count.